import { ChevronLeftIcon, ChevronRightIcon } from '@heroicons/react/24/outline';
import { useMemo } from 'react';

interface PaginationProps {
    totalItems: number;
    itemsPerPage: number;
    currentPage?: number;
    onPageChange?: (page: number) => void;
}
export function Pagination({
    totalItems,
    itemsPerPage,
    currentPage = 1,
    onPageChange = () => { },
}: PaginationProps) {
    const STYLE_CONFIG = {
        colors: {
            primary: 'bg-primary', // USAF Blue
            hover: 'hover:bg-[#00264d]', // Darker USAF Blue
            disabled: 'bg-disabled',
            text: {
                primary: 'text-primary',
                light: 'text-white',
                secondary: 'text-tertiary-400'
            }
        },
        components: {
            container: `
                flex items-center justify-between
                px-4 py-3 sm:px-6
            `,
            pagination: `
                inline-flex shadow-sm rounded-md
                divide-x divide-gray-200
            `,
            button: `
                relative inline-flex items-center justify-center
                min-w-[2.5rem] h-10
                text-sm font-medium
                transition-colors duration-200
                focus:outline-none focus:ring-2 focus:ring-primary focus:ring-offset-2
            `
        }
    };
    // Memoized calculations
    const totalPages = useMemo(() => Math.ceil(totalItems / itemsPerPage), [totalItems, itemsPerPage]);
    const startItem = (currentPage - 1) * itemsPerPage + 1;
    const endItem = Math.min(currentPage * itemsPerPage, totalItems);

    // Navigation handlers
    const handlePrevious = () => currentPage > 1 && onPageChange(currentPage - 1);
    const handleNext = () => currentPage < totalPages && onPageChange(currentPage + 1);

    // Generate page numbers with improved logic
    const getPageNumbers = () => {
        const maxVisiblePages = 5;
        if (totalPages <= maxVisiblePages) {
            return Array.from({ length: totalPages }, (_, i) => i + 1);
        }
        if (currentPage <= 3) {
            return [1, 2, 3, '...', totalPages];
        }
        if (currentPage >= totalPages - 2) {
            return [1, '...', totalPages - 2, totalPages - 1, totalPages];
        }
        return [
            1,
            '...',
            currentPage - 1,
            currentPage,
            currentPage + 1,
            '...',
            totalPages
        ];
    };

    const renderPageButton = (pageNum: number | string, index: number) => {
        if (pageNum === '...') {
            return (
                <span
                    key={`ellipsis-${index}`}
                    className={`
                        ${STYLE_CONFIG.components.button}
                        ${STYLE_CONFIG.colors.text.secondary}
                        bg-white   
                    `}
                >
                    &#8230;
                </span>
            );
        }

        const isCurrentPage = currentPage === pageNum;
        const buttonStyle = isCurrentPage
            ? `
                ${STYLE_CONFIG.components.button}
                ${STYLE_CONFIG.colors.primary}
                ${STYLE_CONFIG.colors.text.light}
                ${STYLE_CONFIG.colors.hover}
              `
            : `
                ${STYLE_CONFIG.components.button}
                bg-white
                ${STYLE_CONFIG.colors.text.primary}
                hover:bg-gray-50
              `;

        return (
            <button
                key={pageNum}
                onClick={() => onPageChange(pageNum as number)}
                className={buttonStyle}
            >
                {pageNum}
            </button>
        );
    };
    return (
        <div className={STYLE_CONFIG.components.container}>
            <div className="flex-1 flex items-center justify-between">
                <div>
                    <p className={STYLE_CONFIG.colors.text.secondary}>
                        Showing <span className="font-semibold">{startItem}</span> to{' '}
                        <span className="font-semibold">{endItem}</span> of{' '}
                        <span className="font-semibold">{totalItems}</span> results
                    </p>
                </div>

                <nav className="relative z-0 inline-flex">
                    <div className={STYLE_CONFIG.components.pagination}>
                        <button
                            onClick={handlePrevious}
                            disabled={currentPage === 1}
                            className={`
                                ${STYLE_CONFIG.components.button}
                                rounded-l-md
                                ${currentPage === 1 ? 'opacity-50 cursor-not-allowed' : ''}
                                bg-white
                                ${STYLE_CONFIG.colors.text.primary}
                                hover:bg-gray-50
                            `}
                        >
                            <ChevronLeftIcon className="h-5 w-5" />
                        </button>

                        {getPageNumbers().map(renderPageButton)}

                        <button
                            onClick={handleNext}
                            disabled={currentPage === totalPages}
                            className={`
                                ${STYLE_CONFIG.components.button}
                                rounded-r-md
                                ${currentPage === totalPages ? 'opacity-50 cursor-not-allowed' : ''}
                                bg-white
                                ${STYLE_CONFIG.colors.text.primary}
                                hover:bg-gray-50
                            `}
                        >
                            <ChevronRightIcon className="h-5 w-5" />
                        </button>
                    </div>
                </nav>
            </div>
        </div>
    );
}