import { useState } from 'react'
import { Input, Button, Card, Steps, Tag, Spin, message } from 'antd'
import { SearchOutlined, SafetyCertificateOutlined } from '@ant-design/icons'

interface FeedbackStatus {
  status: 'pending' | 'in-progress' | 'resolved'
  ticketId: string
  submittedDate: string
  lastUpdate: string
  title: string
}

const { Step } = Steps

export default function LetterProgressPage() {
  const [feedbackId, setFeedbackId] = useState('')
  const [status, setStatus] = useState<FeedbackStatus | null>(null)
  const [loading, setLoading] = useState(false)
  const [error, setError] = useState('')

  const validateInput = () => {
    if (!feedbackId.trim()) {
      setError('请输入有效的问题编号')
      return false
    }
    if (!/^USAF-\d{4}-\d{4}$/.test(feedbackId)) {
      setError('问题编号格式不正确，应为USAF-YYYY-NNNN')
      return false
    }
    setError('')
    return true
  }

  const mockLookup = () => {
    if (!validateInput()) return

    setLoading(true)
    setTimeout(() => {
      setStatus({
        status: 'in-progress',
        ticketId: feedbackId,
        submittedDate: '2025-01-15',
        lastUpdate: '2025-01-21',
        title: 'Aircraft Maintenance Schedule Inquiry'
      })
      setLoading(false)
    }, 1000)
  }

  const getStatusColor = (status: string) => {
    switch (status) {
      case 'pending':
        return 'orange'
      case 'in-progress':
        return 'blue'
      case 'resolved':
        return 'green'
      default:
        return 'gray'
    }
  }

  return (
    <div className="min-h-screen bg-white" style={{ fontFamily: 'Arial, sans-serif' }}>
      {/* Header */}
      <header className="bg-[#003366] p-8 text-white">
        <div className="container mx-auto flex items-center">
          <SafetyCertificateOutlined className="text-4xl mr-4" />
          <div>
            <h1 className="text-3xl font-bold mb-2">USAF Feedback Tracking System</h1>
            <p className="text-lg">Enter your ticket ID to track progress</p>
          </div>
        </div>
      </header>

      {/* Main Content */}
      <main className="container mx-auto px-4 py-8">
        {/* Search Section */}
        <Card className="mb-8 border border-gray-200">
          <div className="space-y-4">
            <label className="block text-lg font-medium text-[#003366]">
              Ticket ID
            </label>
            <div className="flex gap-4">
              <Input
                prefix={<SearchOutlined className="text-[#003366]" />}
                size="large"
                value={feedbackId}
                onChange={(e) => setFeedbackId(e.target.value)}
                placeholder="e.g. USAF-2025-0123"
                status={error ? 'error' : ''}
                className="border border-gray-300"
              />
              <Button
                type="primary"
                size="large"
                icon={<SearchOutlined />}
                loading={loading}
                onClick={mockLookup}
                style={{ backgroundColor: '#003366', borderColor: '#003366' }}
              >
                Track
              </Button>
            </div>
            {error && <p className="text-red-600 text-sm">{error}</p>}
          </div>
        </Card>

        {/* Results Section */}
        {status && (
          <Card>
            <div className="space-y-6">
              {/* Header */}
              <div className="flex items-center justify-between border-b pb-4">
                <h2 className="text-xl font-semibold text-[#003366]">
                  Ticket Details
                </h2>
                <Tag
                  color={getStatusColor(status.status)}
                  className="font-bold uppercase"
                >
                  {status.status}
                </Tag>
              </div>

              {/* Details Grid */}
              <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-6">
                <div>
                  <p className="text-sm text-gray-600">Ticket ID</p>
                  <p className="font-medium text-[#003366]">{status.ticketId}</p>
                </div>
                <div>
                  <p className="text-sm text-gray-600">Submitted Date</p>
                  <p className="font-medium text-[#003366]">{status.submittedDate}</p>
                </div>
                <div>
                  <p className="text-sm text-gray-600">Last Update</p>
                  <p className="font-medium text-[#003366]">{status.lastUpdate}</p>
                </div>
                <div>
                  <p className="text-sm text-gray-600">Subject</p>
                  <p className="font-medium text-[#003366]">{status.title}</p>
                </div>
              </div>

              {/* Progress Timeline */}
              <div className="mt-8">
                <Steps
                  current={status.status === 'pending' ? 0 : status.status === 'in-progress' ? 1 : 2}
                  className="usa-progress"
                >
                  <Step
                    title="Submitted"
                    description="Ticket received"
                    icon={<SafetyCertificateOutlined />}
                  />
                  <Step
                    title="In Progress"
                    description="Under review"
                    icon={<SafetyCertificateOutlined />}
                  />
                  <Step
                    title="Resolved"
                    description="Ticket completed"
                    icon={<SafetyCertificateOutlined />}
                  />
                </Steps>
              </div>
            </div>
          </Card>
        )}
      </main>
    </div>
  )
}
