import { createContext, useContext, ReactNode, useEffect } from "react";
import { useForm, FormProvider, SubmitHandler } from "react-hook-form";
import { zodResolver } from "@hookform/resolvers/zod";
import { z } from "zod";
import { api, usePost } from "@nice/client";
// import { PostDto, PostLevel, PostStatus } from "@nice/common";
// import { api, usePost } from "@nice/client";
import toast from "react-hot-toast";
import { useNavigate } from "react-router-dom";
import { Post, PostType } from "@nice/common";
// 定义帖子表单验证 Schema

const letterSchema = z.object({
	title: z.string().min(1, "标题不能为空"),
	content: z.string().min(1, "内容不能为空"),
	resources: z.array(z.string()).nullish(),
	isPublic: z.boolean().nullish(),
	signature: z.string().nullish(),
	meta: z
		.object({
			tags: z.array(z.string()).default([]),
			signature: z.string().nullish(),
		})
		.default({
			tags: [],
			signature: null,
		}),
});
// 定义课程表单验证 Schema

export type LetterFormData = z.infer<typeof letterSchema>;
interface LetterEditorContextType {
	onSubmit: SubmitHandler<LetterFormData>;
	receiverId?: string;
	termId?: string;
	part?: string;
	// course?: PostDto;
}
interface LetterFormProviderProps {
	children: ReactNode;
	receiverId?: string;
	termId?: string;
	part?: string;
}
const LetterEditorContext = createContext<LetterEditorContextType | null>(null);
export function LetterFormProvider({
	children,
	receiverId,
	termId,
	// editId,
}: LetterFormProviderProps) {
	const { create } = usePost();
	const navigate = useNavigate();
	const methods = useForm<LetterFormData>({
		resolver: zodResolver(letterSchema),
		defaultValues: {
			resources: [],
			meta: {
				tags: [],
			},
		},
	});
	const onSubmit: SubmitHandler<LetterFormData> = async (
		data: LetterFormData
	) => {
		try {
			const result = await create.mutateAsync({
				data: {
					type: PostType.POST,
					termId: termId,
					receivers: {
						connect: [receiverId].filter(Boolean).map((id) => ({
							id,
						})),
					},
					...data,
					resources: data.resources?.length
						? {
								connect: data.resources.map((id) => ({
									id,
								})),
							}
						: undefined,
				},
			});
			navigate(`/course/${result.id}/detail`, { replace: true });
			toast.success("发送成功！");

			methods.reset(data);
		} catch (error) {
			console.error("Error submitting form:", error);
			toast.error("操作失败，请重试！");
		}
	};
	return (
		<LetterEditorContext.Provider
			value={{
				onSubmit,
				receiverId,
				termId,
			}}>
			<FormProvider {...methods}>{children}</FormProvider>
		</LetterEditorContext.Provider>
	);
}

export const useLetterEditor = () => {
	const context = useContext(LetterEditorContext);
	if (!context) {
		throw new Error(
			"useLetterEditor must be used within LetterFormProvider"
		);
	}
	return context;
};
