import { useFormContext } from "react-hook-form";
import { motion } from "framer-motion";
import {
	LetterFormData,
	useLetterEditor,
} from "../context/LetterEditorContext";
import { FormQuillInput } from "@web/src/components/common/form/FormQuillInput";
import { api } from "@nice/client";
import {
	UserIcon,
	FolderIcon,
	HashtagIcon,
	DocumentTextIcon,
} from "@heroicons/react/24/outline";
import FileUploader from "@web/src/components/common/uploader/FileUploader";
import { FormTags } from "@web/src/components/common/form/FormTags";
import { FormSignature } from "@web/src/components/common/form/FormSignature";
import { FormCheckbox } from "@web/src/components/common/form/FormCheckbox";

export function LetterBasicForm() {
	const {
		handleSubmit,
		getValues,
		formState: { errors },
	} = useFormContext<LetterFormData>();
	const { onSubmit, receiverId, termId } = useLetterEditor();
	const { data: receiver } = api.staff.findFirst.useQuery(
		{
			where: {
				id: receiverId,
			},
		},
		{
			enabled: !!receiverId,
		}
	);
	const { data: term } = api.term.findFirst.useQuery(
		{
			where: { id: termId },
		},
		{ enabled: !!termId }
	);

	const formControls = {
		hidden: { opacity: 0, y: 20 },
		visible: (i: number) => ({
			opacity: 1,
			y: 0,
			transition: {
				delay: i * 0.2,
				duration: 0.5,
			},
		}),
	};

	return (
		<motion.form
			className="w-full space-y-6 p-8 "
			initial={{ opacity: 0, scale: 0.95 }}
			animate={{ opacity: 1, scale: 1 }}
			transition={{ duration: 0.5 }}>
			{/* 收件人和板块信息行 */}
			<div className="flex justify-start items-center gap-8">
				<motion.div
					custom={0}
					initial="hidden"
					animate="visible"
					variants={formControls}
					className="flex items-center text-lg font-semibold text-[#00308F]">
					<UserIcon className="w-5 h-5 mr-2 text-[#00308F]" />
					<div>收件人：{receiver?.showname}</div>
				</motion.div>

				<motion.div
					custom={1}
					initial="hidden"
					animate="visible"
					variants={formControls}
					className="flex items-center text-lg font-semibold text-[#00308F]">
					<FolderIcon className="w-5 h-5 mr-2 text-[#00308F]" />
					<div>板块：{term?.name}</div>
				</motion.div>
			</div>
			{/* 主题输入框 */}
			<motion.div
				custom={2}
				initial="hidden"
				animate="visible"
				variants={formControls}>
				<label className="block text-sm font-medium text-gray-700 mb-2">
					<HashtagIcon className="w-5 h-5 inline mr-2 text-[#00308F]" />
					主题
				</label>
				{/* <FormInput
					maxLength={20}
					name="title"
					placeholder="请输入主题"
				/> */}
			</motion.div>
			{/* 标签输入 */}
			<motion.div
				custom={4}
				initial="hidden"
				animate="visible"
				variants={formControls}
				className="space-y-2">
				<label className="block text-sm font-medium text-gray-700 mb-2">
					<HashtagIcon className="w-5 h-5 inline mr-2 text-[#00308F]" />
					标签
				</label>
				<FormTags
					name="meta.tags"
					placeholder="输入标签后按回车添加"
					maxTags={20}
				/>
			</motion.div>
			{/* 内容输入框 */}
			<motion.div
				custom={3}
				initial="hidden"
				animate="visible"
				variants={formControls}>
				<label className="block text-sm font-medium text-gray-700 mb-2">
					<DocumentTextIcon className="w-5 h-5 inline mr-2 text-[#00308F]" />
					内容
				</label>
				<FormQuillInput
					maxLength={400}
					name="content"
					placeholder="请输入内容"
				/>
			</motion.div>
			<FileUploader></FileUploader>
			<motion.div className="flex items-center justify-end gap-8 border-t border-gray-100 pt-2">
				<motion.div
					custom={3}
					initial="hidden"
					animate="visible"
					variants={formControls}
					className="flex justify-end">
					<FormCheckbox
						name="isPublic"
						label="是否公开"
						defaultChecked
					/>
				</motion.div>
{/* 
				<motion.div
					custom={5}
					initial="hidden"
					animate="visible"
					variants={formControls}
					className="flex justify-end">
					<FormSignature
						name="meta.signature"
						width="w-32"
						placeholder="添加个性签名"
						maxLength={20}
						viewMode={false}
					/>
				</motion.div> */}

				<motion.button
					onClick={handleSubmit(onSubmit)}
					className="px-4 py-2 bg-[#00308F] hover:bg-[#041E42] text-white font-bold rounded-lg 
              transform transition-all duration-200 hover:scale-105 focus:ring-2 focus:ring-[#00308F]/50"
					whileHover={{ scale: 1.02 }}
					whileTap={{ scale: 0.98 }}>
					提交
				</motion.button>
			</motion.div>
		</motion.form>
	);
}
