import React, { useContext, useState } from "react";
import { motion } from "framer-motion";
import { PaperAirplaneIcon } from "@heroicons/react/24/solid";
import { CommandLineIcon } from "@heroicons/react/24/outline";
import QuillEditor from "@web/src/components/common/editor/quill/QuillEditor";
import { PostDetailContext } from "./context/PostDetailContext";
import { usePost } from "@nice/client";
import { PostType } from "@nice/common";
import toast from "react-hot-toast";
import { isContentEmpty } from "./utils";

export default function PostCommentEditor() {
	const { post } = useContext(PostDetailContext);
	const [content, setContent] = useState("");
	const [isPreview, setIsPreview] = useState(false);
	const { create } = usePost();
	const handleSubmit = async (e: React.FormEvent) => {
		e.preventDefault();
		if (isContentEmpty(content)) {
			toast.error("内容不得为空");
			return;
		}

		try {
			await create.mutateAsync({
				data: {
					type: PostType.POST_COMMENT,
					parentId: post?.id,
					content: content,
				},
			});
			toast.success("发布成功！");
			setContent("");
		} catch (error) {
			toast.error("发布失败，请稍后重试");
			console.error("Error posting comment:", error);
		}
		// TODO: 实现提交逻辑
		console.log("Submitting:", content);
		setContent("");
	};

	return (
		<motion.div
			initial={{ opacity: 0, y: 20 }}
			animate={{ opacity: 1, y: 0 }}
			className="w-full mx-auto mt-4">
			<form onSubmit={handleSubmit} className="space-y-3">
				<div className="relative rounded-lg border border-slate-200 bg-white shadow-sm">
					{!isPreview ? (
						<QuillEditor
							value={content}
							onChange={setContent}
							placeholder="写下你的回复..."
							className="bg-transparent"
							theme="snow"
							minRows={3}
							maxRows={12}
							modules={{
								toolbar: [
									["bold", "italic", "strike"],
									["blockquote", "code-block"],
									[{ list: "ordered" }, { list: "bullet" }],
									["link"],
									["clean"],
								],
							}}
							style={
								{
									"--ql-border-color": "transparent",
									"--ql-toolbar-bg": "rgb(248, 250, 252)", // slate-50
								} as React.CSSProperties
							}
						/>
					) : (
						<motion.div
							initial={{ opacity: 0 }}
							animate={{ opacity: 1 }}
							className="ql-editor p-4 min-h-[120px] text-slate-800 prose prose-slate max-w-none quill-editor-container"
							dangerouslySetInnerHTML={{ __html: content }}
						/>
					)}
				</div>

				<div className="flex items-center justify-end">
					{/* <motion.button
						type="button"
						onClick={() => setIsPreview(!isPreview)}
						whileHover={{ scale: 1.02 }}
						whileTap={{ scale: 0.98 }}
						className={`flex items-center space-x-1 px-3 py-1.5 rounded-md
                                  transition-colors ${
										isPreview
											? "bg-blue-600 text-white"
											: "bg-slate-100 text-slate-600 hover:bg-slate-200"
									}`}>
						<CommandLineIcon className="w-5 h-5" />
						<span>{isPreview ? "编辑" : "预览"}</span>
					</motion.button> */}

					<motion.button
						type="submit"
						disabled={isContentEmpty(content)}
						whileHover={{ scale: 1.02 }}
						whileTap={{ scale: 0.98 }}
						className={`flex items-center space-x-2 px-4 py-2 rounded-md
                                  ${
										!isContentEmpty(content)
											? "bg-blue-600 text-white hover:bg-blue-700"
											: "bg-slate-100 text-slate-400 cursor-not-allowed"
									} transition-colors`}>
						<PaperAirplaneIcon className="w-4 h-4" />
						<span>提交</span>
					</motion.button>
				</div>
			</form>
		</motion.div>
	);
}
