import React, {
	useContext,
	useMemo,
	useEffect,
	useRef,
	useCallback,
} from "react";
import { PostDetailContext } from "./context/PostDetailContext";
import { api, useVisitor } from "@nice/client";
import { postDetailSelect, PostDto, PostType, Prisma } from "@nice/common";
import { motion, AnimatePresence } from "framer-motion";
import PostCommentCard from "./PostCommentCard";
import { useInView } from "react-intersection-observer";
import { LoadingCard } from "@web/src/components/models/post/detail/LoadingCard";

export default function PostCommentList() {
	const { post } = useContext(PostDetailContext);
	const { ref: loadMoreRef, inView } = useInView();
	const { postParams } = useVisitor();
	const params: Prisma.PostFindManyArgs = useMemo(() => {
		return {
			where: {
				parentId: post?.id,
				type: PostType.POST_COMMENT,
			},
			select: postDetailSelect,
			orderBy: [
				{
					createdAt: "desc",
				},
			],
			take: 3,
		};
	}, [post]);
	const {
		data: queryData,
		fetchNextPage,
		refetch,
		isPending,
		isFetchingNextPage,
		hasNextPage,
		isLoading,
		isRefetching,
	} = api.post.findManyWithCursor.useInfiniteQuery(params, {
		enabled: !!post?.id,
		getNextPageParam: (lastPage) => lastPage.nextCursor,
	});
	useEffect(() => {
		if (post?.id) {
			postParams.addItem(params);
			return () => {
				postParams.removeItem(params);
			};
		}
	}, [post, params]);
	const items = useMemo<PostDto[]>(() => {
		return queryData?.pages?.flatMap((page: any) => page.items) || [];
	}, [queryData]);

	useEffect(() => {
		if (inView && hasNextPage && !isFetchingNextPage) {
			fetchNextPage();
		}
	}, [inView, hasNextPage, isFetchingNextPage, fetchNextPage]);

	if (isLoading) {
		return <LoadingCard />;
	}

	if (!items.length) {
		return (
			<motion.div
				initial={{ opacity: 0, y: 20 }}
				animate={{ opacity: 1, y: 0 }}
				className="text-center py-12 text-slate-500">
				暂无回复，来发表第一条回复吧
			</motion.div>
		);
	}

	return (
		<div className="space-y-4 mt-6">
			<AnimatePresence mode="popLayout">
				{items.map((comment, index) => (
					<motion.div
						key={comment.id}
						initial={{ opacity: 0, y: 20 }}
						animate={{ opacity: 1, y: 0 }}
						exit={{ opacity: 0, scale: 0.95 }}
						transition={{
							duration: 0.2,
							delay: index * 0.05,
						}}>
						<PostCommentCard post={comment} index={index} />
					</motion.div>
				))}
			</AnimatePresence>

			{/* 加载更多触发器 */}
			<div ref={loadMoreRef} className="h-20">
				{isFetchingNextPage ? (
					<div className="flex justify-center py-4">
						<div className="w-6 h-6 border-2 border-[#00308F] border-t-transparent rounded-full animate-spin" />
					</div>
				) : (
					items.length > 0 &&
					!hasNextPage && (
						<motion.div
							initial={{ opacity: 0, y: 10 }}
							animate={{ opacity: 1, y: 0 }}
							transition={{ duration: 0.5 }}
							className="flex flex-col items-center py-4 space-y-2">
							<div className="h-px w-16 bg-gradient-to-r from-transparent via-[#00308F]/30 to-transparent" />
							<span className="text-sm text-gray-500 font-medium">
								已加载全部评论
							</span>
							<motion.div
								className="h-px w-16 bg-gradient-to-r from-transparent via-[#00308F]/30 to-transparent"
								initial={{ width: "4rem" }}
								animate={{ width: "12rem" }}
								transition={{
									duration: 1.5,
									repeat: Infinity,
									repeatType: "reverse",
									ease: "easeInOut",
								}}
							/>
						</motion.div>
					)
				)}
			</div>
		</div>
	);
}
